searchData={"items":[{"type":"module","title":"Pager","doc":"Provides pagination functionality for Ecto queries.\n\nThis module offers a simple way to paginate Ecto query results with automatic\nhandling of page boundaries, flexible parameter types, and consistent return structure.","ref":"Pager.html"},{"type":"function","title":"Pager.page/4","doc":"Paginates an Ecto query with flexible parameter handling.\n\n# Parameters\n\n* `query` - An Ecto query to paginate\n* `repo` - The Ecto repo to execute the query\n* `page` - Page number (integer or string, defaults to 1)\n* `per_page` - Items per page (integer or string, defaults to 50)\n\n# Examples\n\n    iex> alias Pager.{User, Repo}\n    iex> query = from(u in User)\n    iex> result = Pager.page(query, Repo, 1, 20)\n    iex> Map.drop(result, [:list])\n    %{count: 0, first: 1, has_next: false, has_prev: false, last: 0, next_page: 2, page: 1, prev_page: 0}\n\n    # String parameters (e.g. from Phoenix params)\n    iex> alias Pager.{User, Repo}\n    iex> query = from(u in User)\n    iex> result = Pager.page(query, Repo, \"2\", \"10\")\n    iex> Map.drop(result, [:list])\n    %{count: 0, first: 11, has_next: false, has_prev: true, last: 0, next_page: 3, page: 2, prev_page: 1}\n\n    # With defaults\n    iex> alias Pager.{User, Repo}\n    iex> query = from(u in User)\n    iex> result = Pager.page(query, Repo, nil, 50)\n    iex> Map.drop(result, [:list])\n    %{count: 0, first: 1, has_next: false, has_prev: false, last: 0, next_page: 2, page: 1, prev_page: 0}","ref":"Pager.html#page/4"},{"type":"type","title":"Pager.page_result/0","doc":"Pagination result containing pagination metadata and list of items.\n\nFields:\n* `has_next` - Indicates if there are more pages after the current one\n* `has_prev` - Indicates if there are pages before the current one\n* `prev_page` - Previous page number\n* `page` - Current page number\n* `next_page` - Next page number\n* `first` - Index of first item on current page\n* `last` - Index of last item on current page\n* `count` - Total number of items across all pages\n* `list` - List of results/items on the current page","ref":"Pager.html#t:page_result/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.0"}}